package sklep.rest;

import java.net.URI;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.server.ResponseStatusException;

import jakarta.ws.rs.Consumes;
import jakarta.ws.rs.DELETE;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.POST;
import jakarta.ws.rs.PUT;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.PathParam;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.core.Response;
import jakarta.ws.rs.core.UriBuilder;
import sklep.model.Product;
import sklep.photo.PhotoUtil;
import sklep.repository.ProductRepository;

@Path("/products")
public class RProducts {
	@Autowired
	private ProductRepository productRepository;
    @Autowired
    private PhotoUtil photoUtil;


	@GET
	@Produces({"application/json", "application/xml", "text/plain"})
	public List<Product> getAllProducts() {
		return productRepository.findAll();
	}
	
	@GET
	@Path("/{id}")
	@Produces({"application/json", "application/xml", "text/plain"})
	public Product readOne(@PathParam("id") int productId) {
		return productRepository
				.findById(productId)
				.orElseThrow(() -> new ResponseStatusException(HttpStatus.NOT_FOUND));	}
    
   
	@POST
	@Consumes({"application/json", "application/xml"})
	public Response saveProduct(Product product)  {
        productRepository.save(product);
		URI uri = UriBuilder
				.fromResource(RProducts.class)
				.path(String.valueOf(product.getProductId()))
				.build();
		return Response.created(uri).build();
	}
	
	@DELETE
	@Path("/{id}")
	public void delete(@PathParam("id") int productId) {
		productRepository.deleteById(productId);
	}
	
    @GET
    @Path("/{id}/photo")
    @Produces("image/jpeg")
    public byte[] getPhoto(@PathParam("id") int productId) {
            return photoUtil.readBytes(productId);
    }       
    
    @PUT
    @Path("/{id}/photo")
    @Consumes("image/jpeg")
    public void uploadPhoto(@PathParam("id") int productId, byte[] bytes) {
            photoUtil.writeBytes(productId, bytes);
    }

}
